Struct Check
pub struct Check {
pub name: String,
pub expr: String,
pub no_inherit: bool,
}Expand description
A constraint which states that a value must satisfy the following Boolean expression
Fields
name: Stringexpr: StringThe Boolean expression that must be satisfied
no_inherit: boolIf marked with NO INHERIT, the constraint will not propogate to child tables