Struct ColumnInfo
pub struct ColumnInfo {
pub name: String,
pub col_type: ColumnType,
pub default: Option<ColumnExpression>,
pub generated: Option<ColumnExpression>,
pub not_null: Option<NotNull>,
pub is_identity: bool,
}Fields
name: StringThe name of the column
col_type: ColumnTypeThe type of the column with any additional definitions such as the precision or the character set
default: Option<ColumnExpression>The default value experssion for this column, if any
generated: Option<ColumnExpression>The generation expression for this column, if it is a generated colum
not_null: Option<NotNull>is_identity: boolImplementations
impl ColumnInfo
impl ColumnInfo
pub fn write(&self) -> ColumnDef
pub fn write_col_type(&self) -> ColumnType