Struct Exclusion
pub struct Exclusion {
pub name: String,
pub using: String,
pub columns: Vec<String>,
pub operation: String,
}Expand description
A constraint that ensures that, if any two rows are compared on the specified columns or expressions using the specified operators, at least one of these operator comparisons returns false or null
Fields
name: Stringusing: Stringcolumns: Vec<String>operation: StringTrait Implementations
impl StructuralPartialEq for Exclusion