Struct PrimaryKey
pub struct PrimaryKey {
pub name: String,
pub columns: Vec<String>,
}Expand description
A constraint stating that the given columns act as a unique identifier for rows in the table. This implies that the columns are not null and are unique together
Fields
name: Stringcolumns: Vec<String>Implementations
impl PrimaryKey
impl PrimaryKey
pub fn write(&self) -> IndexCreateStatement